@@ -3,7 +3,7 @@
 
 /* Some wrappers for asn1/asn1c/ContentInfo.h. */
 
-#include "uri.h"
+#include "types/uri.h"
 #include "asn1/asn1c/ContentInfo.h"
 
 int content_info_load(struct rpki_uri *, struct ContentInfo **);
