@@ -145,12 +145,19 @@ struct rpki_config {
 		} retry;
 		/* User-Agent header set at requests */
 		char *user_agent;
-		/* Timeout in seconds for the connect phase */
+		/* CURLOPT_CONNECTTIMEOUT for our HTTP transfers. */
 		unsigned int connect_timeout;
-		/* Maximum allowed time that a request can take */
+		/* CURLOPT_TIMEOUT for our HTTP transfers. */
 		unsigned int transfer_timeout;
-		/* Maximum idle time during a request */
-		unsigned int idle_timeout;
+		/* CURLOPT_LOW_SPEED_LIMIT for our HTTP transfers. */
+		unsigned int low_speed_limit;
+		/* CURLOPT_LOW_SPEED_TIME for our HTTP transfers. */
+		unsigned int low_speed_time;
+		/*
+		 * CURLOPT_MAXFILESIZE, except it also works for unknown size
+		 * files. (Though this is reactive, not preventive.)
+		 */
+		unsigned int max_file_size;
 		/* Directory where CA certs to verify peers are found */
 		char *ca_path;
 	} http;
@@ -208,6 +215,7 @@ struct rpki_config {
 	bool init_tals;
 	/* Download AS0 TALs into --tal? */
 	bool init_tal0s;
+
 	/* Deprecated; currently does nothing. */
 	unsigned int init_tal_locations;
 
@@ -301,7 +309,7 @@ static const struct option_field options[] = {
 		.name = "sync-strategy",
 		.type = &gt_sync_strategy,
 		.offset = offsetof(struct rpki_config, sync_strategy),
-		.doc = "RSYNC download strategy. Will be deprecated, use 'rsync.strategy' instead.",
+		.doc = "RSYNC download strategy. Deprecated; use 'rsync.strategy' instead.",
 	}, {
 		.id = 2001,
 		.name = "shuffle-uris",
@@ -463,7 +471,7 @@ static const struct option_field options[] = {
 		.doc = "Priority of execution to fetch repositories files, a higher value means higher priority",
 		.min = 0,
 		.max = 100,
-	},{
+	}, {
 		.id = 3002,
 		.name = "rsync.strategy",
 		.type = &gt_rsync_strategy,
@@ -485,7 +493,7 @@ static const struct option_field options[] = {
 		.doc = "Period (in seconds) to wait between retries after an RSYNC error ocurred",
 		.min = 0,
 		.max = UINT_MAX,
-	},{
+	}, {
 		.id = 3005,
 		.name = "rsync.program",
 		.type = &gt_string,
@@ -519,13 +527,13 @@ static const struct option_field options[] = {
 		.name = "rrdp.enabled",
 		.type = &gt_rrdp_enabled,
 		.offset = offsetof(struct rpki_config, rrdp.enabled),
-		.doc = "Enables RRDP execution. Will be deprecated, use 'http.enabled' instead.",
+		.doc = "Enables RRDP execution. Deprecated; use 'http.enabled' instead.",
 	}, {
 		.id = 10001,
 		.name = "rrdp.priority",
 		.type = &gt_rrdp_priority,
 		.offset = offsetof(struct rpki_config, rrdp.priority),
-		.doc = "Priority of execution to fetch repositories files, a higher value means higher priority. Will be deprecated, use 'http.priority' instead.",
+		.doc = "Priority of execution to fetch repositories files, a higher value means higher priority. Deprecated; use 'http.priority' instead.",
 		.min = 0,
 		.max = 100,
 	}, {
@@ -533,7 +541,7 @@ static const struct option_field options[] = {
 		.name = "rrdp.retry.count",
 		.type = &gt_rrdp_retry_count,
 		.offset = offsetof(struct rpki_config, rrdp.retry.count),
-		.doc = "Maximum amount of retries whenever there's an error fetching RRDP files. Will be deprecated, use 'http.retry.count' instead.",
+		.doc = "Maximum amount of retries whenever there's an error fetching RRDP files. Deprecated; use 'http.retry.count' instead.",
 		.min = 0,
 		.max = UINT_MAX,
 	}, {
@@ -541,7 +549,7 @@ static const struct option_field options[] = {
 		.name = "rrdp.retry.interval",
 		.type = &gt_rrdp_retry_interval,
 		.offset = offsetof(struct rpki_config, rrdp.retry.interval),
-		.doc = "Period (in seconds) to wait between retries after an error ocurred fetching RRDP files. Will be deprecated, use 'http.retry.interval' instead.",
+		.doc = "Period (in seconds) to wait between retries after an error ocurred fetching RRDP files. Deprecated; use 'http.retry.interval' instead.",
 		.min = 0,
 		.max = UINT_MAX,
 	},
@@ -553,8 +561,7 @@ static const struct option_field options[] = {
 		.type = &gt_rrdp_enabled,
 		.offset = offsetof(struct rpki_config, http.enabled),
 		.doc = "Enables outgoing HTTP requests",
-	},
-	{
+	}, {
 		.id = 9001,
 		.name = "http.priority",
 		.type = &gt_rrdp_priority,
@@ -562,8 +569,7 @@ static const struct option_field options[] = {
 		.doc = "Priority of execution to fetch repositories files, a higher value means higher priority",
 		.min = 0,
 		.max = 100,
-	},
-	{
+	}, {
 		.id = 9002,
 		.name = "http.retry.count",
 		.type = &gt_rrdp_retry_count,
@@ -571,8 +577,7 @@ static const struct option_field options[] = {
 		.doc = "Maximum amount of retries whenever there's an error requesting HTTP URIs",
 		.min = 0,
 		.max = UINT_MAX,
-	},
-	{
+	}, {
 		.id = 9003,
 		.name = "http.retry.interval",
 		.type = &gt_rrdp_retry_interval,
@@ -580,15 +585,13 @@ static const struct option_field options[] = {
 		.doc = "Period (in seconds) to wait between retries after an error ocurred doing HTTP requests",
 		.min = 0,
 		.max = UINT_MAX,
-	},
-	{
+	}, {
 		.id = 9004,
 		.name = "http.user-agent",
 		.type = &gt_string,
 		.offset = offsetof(struct rpki_config, http.user_agent),
 		.doc = "User-Agent to use at HTTP requests, eg. Fort Validator Local/1.0",
-	},
-	{
+	}, {
 		.id = 9005,
 		.name = "http.connect-timeout",
 		.type = &gt_uint,
@@ -596,8 +599,7 @@ static const struct option_field options[] = {
 		.doc = "Timeout for the connect phase",
 		.min = 1,
 		.max = UINT_MAX,
-	},
-	{
+	}, {
 		.id = 9006,
 		.name = "http.transfer-timeout",
 		.type = &gt_uint,
@@ -605,17 +607,39 @@ static const struct option_field options[] = {
 		.doc = "Maximum transfer time (once the connection is established) before dropping the connection",
 		.min = 0,
 		.max = UINT_MAX,
-	},
-	{
+	}, {
 		.id = 9007,
-		.name = "http.idle-timeout",
+		.name = "http.idle-timeout", /* TODO DEPRECATED. */
 		.type = &gt_uint,
-		.offset = offsetof(struct rpki_config, http.idle_timeout),
-		.doc = "Maximum idle time (once the connection is established) during a request before dropping the connection",
+		.offset = offsetof(struct rpki_config, http.low_speed_time),
+		.doc = "Deprecated; currently an alias for --http.low-speed-time. Use --http.low-speed-time instead.",
 		.min = 0,
 		.max = UINT_MAX,
-	},
-	{
+	}, {
+		.id = 9009,
+		.name = "http.low-speed-limit",
+		.type = &gt_uint,
+		.offset = offsetof(struct rpki_config, http.low_speed_limit),
+		.doc = "Average transfer speed (in bytes per second) that the transfer should be below during --http.low-speed-time seconds for Fort to consider it to be too slow. (Slow connections are dropped.)",
+		.min = 0,
+		.max = UINT_MAX,
+	}, {
+		.id = 9010,
+		.name = "http.low-speed-time",
+		.type = &gt_uint,
+		.offset = offsetof(struct rpki_config, http.low_speed_time),
+		.doc = "Seconds that the transfer speed should be below --http.low-speed-limit for the Fort to consider it too slow. (Slow connections are dropped.)",
+		.min = 0,
+		.max = UINT_MAX,
+	}, {
+		.id = 9011,
+		.name = "http.max-file-size",
+		.type = &gt_uint,
+		.offset = offsetof(struct rpki_config, http.max_file_size),
+		.doc = "Fort will refuse to download files larger than this number of bytes.",
+		.min = 0,
+		.max = 2000000000,
+	}, {
 		.id = 9008,
 		.name = "http.ca-path",
 		.type = &gt_string,
@@ -756,8 +780,7 @@ static const struct option_field options[] = {
 		.doc = "ASN1 decoder max stack size, utilized to avoid a stack overflow on large nested ASN1 objects",
 		.min = 1,
 		.max = UINT_MAX,
-	},
-	{
+	}, {
 		.id = 8001,
 		.name = "stale-repository-period",
 		.type = &gt_uint,
@@ -798,8 +821,7 @@ static const struct option_field options[] = {
 		.doc = "Number of threads in the RTR client request thread pool. Also known as the maximum number of client requests the RTR server will be able to handle at the same time.",
 		.min = 1,
 		.max = UINT_MAX,
-	},
-	{
+	}, {
 		.id = 12001,
 		.name = "thread-pool.validation.max",
 		.type = &gt_uint,
@@ -928,6 +950,7 @@ print_config(void)
 {
 	struct option_field const *opt;
 
+	pr_op_info(PACKAGE_STRING);
 	pr_op_info("Configuration {");
 
 	FOREACH_OPTION(options, opt, 0xFFFF)
@@ -946,6 +969,7 @@ set_default_values(void)
 		"--times",
 		"--contimeout=20",
 		"--timeout=15",
+		"--max-size=20MB",
 		"$REMOTE",
 		"$LOCAL",
 	};
@@ -954,6 +978,7 @@ set_default_values(void)
 		"--times",
 		"--contimeout=20",
 		"--timeout=15",
+		"--max-size=20MB",
 		"--dirs",
 		"$REMOTE",
 		"$LOCAL",
@@ -1002,8 +1027,8 @@ set_default_values(void)
 	rpki_config.rsync.enabled = true;
 	rpki_config.rsync.priority = 50;
 	rpki_config.rsync.strategy = RSYNC_ROOT_EXCEPT_TA;
-	rpki_config.rsync.retry.count = 2;
-	rpki_config.rsync.retry.interval = 5;
+	rpki_config.rsync.retry.count = 1;
+	rpki_config.rsync.retry.interval = 4;
 	rpki_config.rsync.program = strdup("rsync");
 	if (rpki_config.rsync.program == NULL) {
 		error = pr_enomem();
@@ -1023,8 +1048,8 @@ set_default_values(void)
 	/* By default, has a higher priority than rsync */
 	rpki_config.http.enabled = true;
 	rpki_config.http.priority = 60;
-	rpki_config.http.retry.count = 2;
-	rpki_config.http.retry.interval = 5;
+	rpki_config.http.retry.count = 1;
+	rpki_config.http.retry.interval = 4;
 	rpki_config.http.user_agent = strdup(PACKAGE_NAME "/" PACKAGE_VERSION);
 	if (rpki_config.http.user_agent == NULL) {
 		error = pr_enomem();
@@ -1032,7 +1057,9 @@ set_default_values(void)
 	}
 	rpki_config.http.connect_timeout = 30;
 	rpki_config.http.transfer_timeout = 0;
-	rpki_config.http.idle_timeout = 15;
+	rpki_config.http.low_speed_limit = 100000;
+	rpki_config.http.low_speed_time = 10;
+	rpki_config.http.max_file_size = 1000000000;
 	rpki_config.http.ca_path = NULL; /* Use system default */
 
 	/*
@@ -1552,9 +1579,21 @@ config_get_http_transfer_timeout(void)
 }
 
 long
-config_get_http_idle_timeout(void)
+config_get_http_low_speed_limit(void)
 {
-	return rpki_config.http.idle_timeout;
+	return rpki_config.http.low_speed_limit;
+}
+
+long
+config_get_http_low_speed_time(void)
+{
+	return rpki_config.http.low_speed_time;
+}
+
+long
+config_get_http_max_file_size(void)
+{
+	return rpki_config.http.max_file_size;
 }
 
 char const *
