@@ -35,7 +35,9 @@ enum mode config_get_mode(void);
 char const *config_get_http_user_agent(void);
 long config_get_http_connect_timeout(void);
 long config_get_http_transfer_timeout(void);
-long config_get_http_idle_timeout(void);
+long config_get_http_low_speed_limit(void);
+long config_get_http_low_speed_time(void);
+long config_get_http_max_file_size(void);
 char const *config_get_http_ca_path(void);
 bool config_get_rsync_enabled(void);
 unsigned int config_get_rsync_priority(void);
@@ -79,7 +81,7 @@ uint32_t config_get_val_log_facility(void);
  */
 void config_set_rsync_enabled(bool);
 void config_set_http_enabled(bool);
-/* TODO (later) This will be deprecated */
+/* TODO (later) Deprecated */
 void config_set_rrdp_enabled(bool);
 
 /* TODO (later) Remove when sync-strategy is fully deprecated */
