@@ -6,10 +6,10 @@
 #include <string.h>
 #include "log.h"
 
-static void
+void
 print_uint(struct option_field const *field, void *value)
 {
-	pr_info("%s: %u", field->name, *((unsigned int *) value));
+	pr_op_info("%s: %u", field->name, *((unsigned int *) value));
 }
 
 int
@@ -21,21 +21,21 @@ parse_argv_uint(struct option_field const *field, char const *str,
 
 	if (field->type->has_arg != required_argument || str == NULL ||
 		    strlen(str) == 0) {
-		return pr_err("Integer options ('%s' in this case) require an argument.",
+		return pr_op_err("Integer options ('%s' in this case) require an argument.",
 		    field->name);
 	}
 
 	errno = 0;
 	parsed = strtoul(str, &tmp, 10);
 	if (errno || *tmp != '\0')
-		return errno ? pr_errno(errno,
+		return errno ? pr_op_errno(errno,
 		    "Value '%s' at '%s' is not an unsigned integer", str,
 		    field->name) :
-		    pr_err("Value '%s' at '%s' is not an unsigned integer",
+		    pr_op_err("Value '%s' at '%s' is not an unsigned integer",
 		    str, field->name);
 
 	if (parsed < field->min || field->max < parsed) {
-		return pr_err("Value of '%s' is out of range (%u-%u).",
+		return pr_op_err("Value of '%s' is out of range (%u-%u).",
 		    field->name, field->min, field->max);
 	}
 
@@ -49,14 +49,14 @@ parse_json_uint(struct option_field const *opt, json_t *json, void *result)
 	json_int_t value;
 
 	if (!json_is_integer(json)) {
-		return pr_err("The '%s' element is not a JSON integer.",
+		return pr_op_err("The '%s' element is not a JSON integer.",
 		    opt->name);
 	}
 
 	value = json_integer_value(json);
 
 	if (value < opt->min || opt->max < value) {
-		return pr_err("Integer '%s' is out of range (%u-%u).",
+		return pr_op_err("Integer '%s' is out of range (%u-%u).",
 		    opt->name, opt->min, opt->max);
 	}
 
