@@ -3,6 +3,6 @@
 
 #include <stddef.h>
 
-int delete_dir_daemon_start(char **, size_t);
+int delete_dir_daemon_start(char **, size_t, char const *);
 
 #endif /* SRC_DELETE_DIR_DAEMON_H_ */
