@@ -4,19 +4,11 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <curl/curl.h>
-#include <sys/stat.h>
 #include "common.h"
 #include "config.h"
 #include "file.h"
 #include "log.h"
 
-/* HTTP Response Code 200 (OK) */
-#define HTTP_OK			200
-/* HTTP Response Code 304 (Not Modified) */
-#define HTTP_NOT_MODIFIED	304
-/* HTTP Response Code 400 (Bad Request) */
-#define HTTP_BAD_REQUEST	400
-
 struct http_handler {
 	CURL *curl;
 	char errbuf[CURL_ERROR_SIZE];
@@ -67,12 +59,52 @@ setopt_long(CURL *curl, CURLoption opt, long value)
 	}
 }
 
+struct write_callback_arg {
+	size_t total_bytes;
+	int error;
+	FILE *dst;
+};
+
+static size_t
+write_callback(void *data, size_t size, size_t nmemb, void *userp)
+{
+	struct write_callback_arg *arg = userp;
+
+	arg->total_bytes += size * nmemb;
+	if (arg->total_bytes > config_get_http_max_file_size()) {
+		/*
+		 * If the server doesn't provide the file size beforehand,
+		 * CURLOPT_MAXFILESIZE doesn't prevent large file downloads.
+		 *
+		 * Therefore, we cover our asses by way of this reactive
+		 * approach. We already reached the size limit, but we're going
+		 * to reject the file anyway.
+		 */
+		arg->error = -EFBIG;
+		return 0; /* Ugh. See fwrite(3) */
+	}
+
+	return fwrite(data, size, nmemb, arg->dst);
+}
+
 static void
-setopt_writedata(CURL *curl, FILE *file)
+setopt_writefunction(CURL *curl)
 {
 	CURLcode result;
 
-	result = curl_easy_setopt(curl, CURLOPT_WRITEDATA, file);
+	result = curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, write_callback);
+	if (result != CURLE_OK) {
+		fprintf(stderr, "curl_easy_setopt(%d) returned %d: %s\n",
+		    CURLOPT_WRITEFUNCTION, result, curl_easy_strerror(result));
+	}
+}
+
+static void
+setopt_writedata(CURL *curl, struct write_callback_arg *arg)
+{
+	CURLcode result;
+
+	result = curl_easy_setopt(curl, CURLOPT_WRITEDATA, arg);
 	if (result != CURLE_OK) {
 		fprintf(stderr, "curl_easy_setopt(%d) returned %d: %s\n",
 		    CURLOPT_WRITEDATA, result, curl_easy_strerror(result));
@@ -83,7 +115,6 @@ static int
 http_easy_init(struct http_handler *handler)
 {
 	CURL *result;
-	long timeout;
 
 	result = curl_easy_init();
 	if (result == NULL)
@@ -95,10 +126,13 @@ http_easy_init(struct http_handler *handler)
 	    config_get_http_connect_timeout());
 	setopt_long(result, CURLOPT_TIMEOUT,
 	    config_get_http_transfer_timeout());
-
-	timeout = config_get_http_idle_timeout();
-	setopt_long(result, CURLOPT_LOW_SPEED_TIME, timeout);
-	setopt_long(result, CURLOPT_LOW_SPEED_LIMIT, !!timeout);
+	setopt_long(result, CURLOPT_LOW_SPEED_LIMIT,
+	    config_get_http_low_speed_limit());
+	setopt_long(result, CURLOPT_LOW_SPEED_TIME,
+	    config_get_http_low_speed_time());
+	setopt_long(result, CURLOPT_MAXFILESIZE,
+	    config_get_http_max_file_size());
+	setopt_writefunction(result);
 
 	/* Always expect HTTPS usage */
 	setopt_long(result, CURLOPT_SSL_VERIFYHOST, 2L);
@@ -109,13 +143,15 @@ http_easy_init(struct http_handler *handler)
 	setopt_long(result, CURLOPT_HTTPGET, 1L);
 
 	/*
-	 * Response codes >= 400 will be treated as errors
+	 * Treat response codes >= 400 as errors. (In theory, this saves a
+	 * little time by failing early, preventing the pointless download.)
 	 *
 	 * "This method is not fail-safe and there are occasions where
 	 * non-successful response codes will slip through, especially when
 	 * authentication is involved (response codes 401 and 407)."
 	 *
-	 * Well, be ready for those scenarios when performing the requests.
+	 * In other words, the HTTP result code still needs to be checked, even
+	 * if the result of curl_easy_perform() is CURLE_OK.
 	 */
 	setopt_long(result, CURLOPT_FAILONERROR, 1L);
 
@@ -136,6 +172,54 @@ curl_err_string(struct http_handler *handler, CURLcode res)
 	    handler->errbuf : curl_easy_strerror(res);
 }
 
+static int
+validate_file_size(char const *uri, struct write_callback_arg *args)
+{
+	float ratio;
+
+	if (args->error == -EFBIG) {
+		pr_val_err("File too big (read: %zu bytes). Rejecting.",
+		    args->total_bytes);
+		return -EFBIG;
+	}
+
+	ratio = args->total_bytes / (float) config_get_http_max_file_size();
+	if (ratio > 0.5f) {
+		pr_op_warn("File size exceeds 50%% of the configured limit (%zu/%ld bytes).",
+		    args->total_bytes, config_get_http_max_file_size());
+	}
+
+	return 0;
+}
+
+static int
+get_http_response_code(struct http_handler *handler, long *http_code,
+    char const *uri)
+{
+	CURLcode res;
+
+	res = curl_easy_getinfo(handler->curl, CURLINFO_RESPONSE_CODE,
+	    http_code);
+	if (res != CURLE_OK) {
+		return pr_op_err("curl_easy_getinfo(CURLINFO_RESPONSE_CODE) returned %d (%s). "
+		    "I think this is supposed to be illegal, so I'll have to drop URI '%s'.",
+		    res, curl_err_string(handler, res), uri);
+	}
+
+	return 0;
+}
+
+static int
+handle_http_response_code(long http_code)
+{
+	/* This is the same logic from CURL, according to its documentation. */
+	if (http_code == 408 || http_code == 429)
+		return EREQFAILED; /* Retry */
+	if (500 <= http_code && http_code < 600)
+		return EREQFAILED; /* Retry */
+	return -EINVAL; /* Do not retry */
+}
+
 /*
  * Fetch data from @uri and write result using @cb (which will receive @arg).
  */
@@ -143,80 +227,109 @@ static int
 http_fetch(struct http_handler *handler, char const *uri, long *response_code,
     long *cond_met, bool log_operation, FILE *file)
 {
-	CURLcode res, res2;
+	struct write_callback_arg args;
+	CURLcode res;
+	long http_code;
 	long unmet = 0;
 
 	handler->errbuf[0] = 0;
 	setopt_str(handler->curl, CURLOPT_URL, uri);
-	setopt_writedata(handler->curl, file);
+
+	args.total_bytes = 0;
+	args.error = 0;
+	args.dst = file;
+	setopt_writedata(handler->curl, &args);
 
 	pr_val_debug("HTTP GET: %s", uri);
 	res = curl_easy_perform(handler->curl);
+	pr_val_debug("Done. Total bytes transferred: %zu", args.total_bytes);
 
-	res2 = curl_easy_getinfo(handler->curl, CURLINFO_RESPONSE_CODE,
-	    response_code);
-	if (res2 != CURLE_OK) {
-		return pr_op_err("curl_easy_getinfo(CURLINFO_RESPONSE_CODE) returned %d (%s). I think this is supposed to be illegal, so I'll have to drop URI '%s'.",
-		    res2, curl_err_string(handler, res2), uri);
+	args.error = validate_file_size(uri, &args);
+	if (args.error)
+		return args.error;
+
+	args.error = get_http_response_code(handler, &http_code, uri);
+	if (args.error)
+		return args.error;
+	*response_code = http_code;
+
+	if (res != CURLE_OK) {
+		pr_val_err("Error requesting URL: %s. (HTTP code: %ld)",
+		    curl_err_string(handler, res), http_code);
+		if (log_operation)
+			pr_op_err("Error requesting URL: %s. (HTTP code: %ld)",
+			    curl_err_string(handler, res), http_code);
+
+		switch (res) {
+		case CURLE_FILESIZE_EXCEEDED:
+			return -EFBIG; /* Do not retry */
+		case CURLE_OPERATION_TIMEDOUT:
+		case CURLE_COULDNT_RESOLVE_HOST:
+		case CURLE_COULDNT_RESOLVE_PROXY:
+		case CURLE_FTP_ACCEPT_TIMEOUT:
+			return EREQFAILED; /* Retry */
+		default:
+			return handle_http_response_code(http_code);
+		}
 	}
 
-	if (res == CURLE_OK) {
-		if (*response_code != HTTP_OK)
-			return 0;
-
+	if (http_code >= 400) {
+		pr_val_err("HTTP result code: %ld", http_code);
+		return handle_http_response_code(http_code);
+	}
+	if (http_code >= 300) {
 		/*
-		 * Scenario: Received an OK code, but the time condition
-		 * (if-modified-since) wasn't actually met (ie. the document
-		 * has not been modified since we last requested it), so handle
-		 * this as a "Not Modified" code.
- 		 *
- 		 * This check is due to old libcurl versions, where the impl
-		 * doesn't let us get the response content since the library
-		 * does the time validation, resulting in "The requested
-		 * document is not new enough".
-		 *
-		 * Update 2021-05-25: I just tested libcurl in my old CentOS 7.7
-		 * VM (which is from October 2019, ie. older than the comments
-		 * above), and it behaves normally.
-		 * Also, the changelog doesn't mention anything about
-		 * If-Modified-Since.
-		 * This glue code is suspicious to me.
-		 *
-		 * For the record, this is how it behaves in my today's Ubuntu,
-		 * as well as my Centos 7.7.1908:
-		 *
-		 * 	if if-modified-since is included:
-		 * 		if page was modified:
-		 * 			HTTP 200
-		 * 			unmet: 0
-		 * 			writefunction called
-		 * 		else:
-		 * 			HTTP 304
-		 * 			unmet: 1
-		 * 			writefunction not called
-		 * 	else:
-		 * 		HTTP OK
-		 * 		unmet: 0
-		 * 		writefunction called
+		 * If you're ever forced to implement this, please remember that
+		 * a malicious server can send us on a wild chase with infinite
+		 * redirects, so there needs to be a limit.
 		 */
-		res = curl_easy_getinfo(handler->curl, CURLINFO_CONDITION_UNMET,
-		    &unmet);
-		if (res == CURLE_OK && unmet == 1)
-			*cond_met = 0;
-		return 0;
+		pr_val_err("HTTP result code: %ld. I don't follow redirects; discarding file.",
+		    http_code);
+		return -EINVAL; /* Do not retry. */
 	}
 
-	if (*response_code >= HTTP_BAD_REQUEST)
-		return pr_val_err("Error requesting URL %s (received HTTP code %ld): %s",
-		    uri, *response_code, curl_err_string(handler, res));
+	pr_val_debug("HTTP result code: %ld", http_code);
 
-	pr_val_err("Error requesting URL %s: %s", uri,
-	    curl_err_string(handler, res));
-	if (log_operation)
-		pr_op_err("Error requesting URL %s: %s", uri,
-		    curl_err_string(handler, res));
+	/*
+	 * Scenario: Received an OK code, but the time condition
+	 * (if-modified-since) wasn't actually met (ie. the document
+	 * has not been modified since we last requested it), so handle
+	 * this as a "Not Modified" code.
+	 *
+	 * This check is due to old libcurl versions, where the impl
+	 * doesn't let us get the response content since the library
+	 * does the time validation, resulting in "The requested
+	 * document is not new enough".
+	 *
+	 * Update 2021-05-25: I just tested libcurl in my old CentOS 7.7
+	 * VM (which is from October 2019, ie. older than the comments
+	 * above), and it behaves normally.
+	 * Also, the changelog doesn't mention anything about
+	 * If-Modified-Since.
+	 * This glue code is suspicious to me.
+	 *
+	 * For the record, this is how it behaves in my today's Ubuntu,
+	 * as well as my Centos 7.7.1908:
+	 *
+	 * 	if if-modified-since is included:
+	 * 		if page was modified:
+	 * 			HTTP 200
+	 * 			unmet: 0
+	 * 			writefunction called
+	 * 		else:
+	 * 			HTTP 304
+	 * 			unmet: 1
+	 * 			writefunction not called
+	 * 	else:
+	 * 		HTTP OK
+	 * 		unmet: 0
+	 * 		writefunction called
+	 */
+	res = curl_easy_getinfo(handler->curl, CURLINFO_CONDITION_UNMET, &unmet);
+	if (res == CURLE_OK && unmet == 1)
+		*cond_met = 0;
 
-	return EREQFAILED;
+	return 0;
 }
 
 static void
@@ -231,11 +344,10 @@ __http_download_file(struct rpki_uri *uri, long *response_code, long ims_value,
 {
 	char const *tmp_suffix = "_tmp";
 	struct http_handler handler;
-	struct stat stat;
 	FILE *out;
 	unsigned int retries;
 	char const *original_file;
-	char *tmp_file, *tmp;
+	char *tmp_file;
 	int error;
 
 	retries = 0;
@@ -246,24 +358,18 @@ __http_download_file(struct rpki_uri *uri, long *response_code, long ims_value,
 	}
 
 	original_file = uri_get_local(uri);
-	tmp_file = strdup(original_file);
+
+	tmp_file = malloc(strlen(original_file) + strlen(tmp_suffix) + 1);
 	if (tmp_file == NULL)
 		return pr_enomem();
-
-	tmp = realloc(tmp_file, strlen(tmp_file) + strlen(tmp_suffix) + 1);
-	if (tmp == NULL) {
-		error = pr_enomem();
-		goto release_tmp;
-	}
-
-	tmp_file = tmp;
+	strcpy(tmp_file, original_file);
 	strcat(tmp_file, tmp_suffix);
 
 	error = create_dir_recursive(tmp_file);
 	if (error)
 		goto release_tmp;
 
-	error = file_write(tmp_file, &out, &stat);
+	error = file_write(tmp_file, &out);
 	if (error)
 		goto delete_dir;
 
@@ -284,12 +390,12 @@ __http_download_file(struct rpki_uri *uri, long *response_code, long ims_value,
 			break; /* Note: Usually happy path */
 
 		if (retries == config_get_http_retry_count()) {
-			pr_val_warn("Max HTTP retries (%u) reached requesting for '%s', won't retry again.",
-			    retries, uri_get_global(uri));
+			if (retries > 0)
+				pr_val_warn("Max HTTP retries (%u) reached. Won't retry again.",
+				    retries);
 			break;
 		}
-		pr_val_warn("Retrying HTTP request '%s' in %u seconds, %u attempts remaining.",
-		    uri_get_global(uri),
+		pr_val_warn("Retrying HTTP request in %u seconds. %u attempts remaining.",
 		    config_get_http_retry_interval(),
 		    config_get_http_retry_count() - retries);
 		retries++;
@@ -368,7 +474,7 @@ http_download_file_with_ims(struct rpki_uri *uri, long value,
 	/* rfc7232#section-3.3:
 	 * "the origin server SHOULD generate a 304 (Not Modified) response"
 	 */
-	if (response == HTTP_NOT_MODIFIED)
+	if (response == 304)
 		return 1;
 
 	/*
@@ -405,7 +511,6 @@ http_direct_download(char const *remote, char const *dest)
 {
 	char const *tmp_suffix = "_tmp";
 	struct http_handler handler;
-	struct stat stat;
 	FILE *out;
 	long response_code;
 	long cond_met;
@@ -425,7 +530,7 @@ http_direct_download(char const *remote, char const *dest)
 	tmp_file = tmp;
 	strcat(tmp_file, tmp_suffix);
 
-	error = file_write(tmp_file, &out, &stat);
+	error = file_write(tmp_file, &out);
 	if (error)
 		goto release_tmp;
 
@@ -433,8 +538,6 @@ http_direct_download(char const *remote, char const *dest)
 	if (error)
 		goto close_file;
 
-	response_code = 0;
-	cond_met = 0;
 	error = http_fetch(&handler, remote, &response_code, &cond_met, true,
 	    out);
 	http_easy_cleanup(&handler);
