@@ -29,6 +29,30 @@ static struct incidence incidences[__INID_MAX] = {
 		"Object isn't DER encoded",
 		INAC_IGNORE,
 	},
+	{
+		INID_MFT_FILE_NOT_FOUND,
+		"incid-file-at-mft-not-found",
+		"File listed at manifest doesn't exist",
+		INAC_ERROR,
+	},
+	{
+		INID_MFT_FILE_HASH_NOT_MATCH,
+		"incid-file-at-mft-hash-not-match",
+		"File hash listed at manifest doesn't match the actual file hash",
+		INAC_ERROR,
+	},
+	{
+		INID_MFT_STALE,
+		"incid-mft-stale",
+		"The current time is after the nextUpdate field at the manifest",
+		INAC_ERROR,
+	},
+	{
+		INID_CRL_STALE,
+		"incid-crl-stale",
+		"The current time is after the nextUpdate field at the CRL",
+		INAC_ERROR,
+	},
 };
 
 static int
@@ -43,7 +67,7 @@ name2id(char const *name, enum incidence_id *id)
 		}
 	}
 
-	return pr_err("Unknown incidence name: %s", name);
+	return pr_op_err("Unknown incidence name: %s", name);
 }
 
 static char const *
@@ -88,7 +112,7 @@ init_action(json_t *json)
 	else if (strcmp("error", action_str) == 0)
 		action = INAC_ERROR;
 	else
-		return pr_err("Unknown incidence action: '%s'", action_str);
+		return pr_op_err("Unknown incidence action: '%s'", action_str);
 
 	incidences[id].action = action;
 	return 0;
@@ -124,7 +148,7 @@ incidence_update(json_t *json)
 	int error;
 
 	if (!json_is_array(json))
-		return pr_err("The incidences JSON element is supposed to be an array.");
+		return pr_op_err("The incidences JSON element is supposed to be an array.");
 
 	json_array_foreach(json, i, child) {
 		error = init_action(child);
@@ -140,10 +164,10 @@ incidence_print(void)
 {
 	array_index i;
 
-	pr_info("Custom incidences:");
+	pr_op_info("Custom incidences:");
 
 	for (i = 0; i < __INID_MAX; i++) {
-		pr_info("  %s (%s): %s", incidences[i].name,
+		pr_op_info("  %s (%s): %s", incidences[i].name,
 		    incidences[i].description,
 		    action2str(incidences[i].action));
 	}
