@@ -24,7 +24,7 @@ lfile_open(const char *file_name, struct line_file **result)
 
 	lfile = malloc(sizeof(struct line_file));
 	if (lfile == NULL)
-		return -ENOMEM;
+		return pr_enomem();
 
 	lfile->file = fopen(file_name, "r");
 	if (lfile->file == NULL) {
@@ -104,7 +104,7 @@ lfile_read(struct line_file *lfile, char **result)
 		free(string);
 		*result = NULL;
 		if (ferror(lfile->file))
-			return pr_errno(error, "Error while reading file");
+			return pr_op_errno(error, "Error while reading file");
 		if (feof(lfile->file))
 			return 0;
 		pr_crit("Supposedly unreachable code reached. ferror:%d feof:%d",
@@ -120,7 +120,7 @@ lfile_read(struct line_file *lfile, char **result)
 	 */
 	for (i = 0; i < len; i++) {
 		if (string[i] == '\0') {
-			pr_err("File '%s' has an illegal null character in its body. Please remove it.",
+			pr_op_err("File '%s' has an illegal null character in its body. Please remove it.",
 			    lfile_name(lfile));
 			free(string);
 			return -EINVAL;
