@@ -36,27 +36,27 @@ ____handle_roa_v4(struct resources *parent, unsigned long asn,
 	if (error)
 		return error;
 
-	pr_debug("ROAIPAddress {");
-	pr_debug("address: %s/%u", v4addr2str(&prefix.addr), prefix.len);
+	pr_val_debug("ROAIPAddress {");
+	pr_val_debug("address: %s/%u", v4addr2str(&prefix.addr), prefix.len);
 
 	if (roa_addr->maxLength != NULL) {
 		error = asn_INTEGER2ulong(roa_addr->maxLength, &max_length);
 		if (error) {
 			if (errno)
-				pr_errno(errno, "Error casting ROA's IPv4 maxLength");
-			error = pr_err("The ROA's IPv4 maxLength isn't a valid unsigned long");
+				pr_val_errno(errno, "Error casting ROA's IPv4 maxLength");
+			error = pr_val_err("The ROA's IPv4 maxLength isn't a valid unsigned long");
 			goto end_error;
 		}
-		pr_debug("maxLength: %lu", max_length);
+		pr_val_debug("maxLength: %lu", max_length);
 
 		if (max_length > 32) {
-			error = pr_err("maxLength (%lu) is out of bounds (0-32).",
+			error = pr_val_err("maxLength (%lu) is out of bounds (0-32).",
 			    max_length);
 			goto end_error;
 		}
 
 		if (prefix.len > max_length) {
-			error = pr_err("Prefix length (%u) > maxLength (%lu)",
+			error = pr_val_err("Prefix length (%u) > maxLength (%lu)",
 			    prefix.len, max_length);
 			goto end_error;
 		}
@@ -66,15 +66,15 @@ ____handle_roa_v4(struct resources *parent, unsigned long asn,
 	}
 
 	if (!resources_contains_ipv4(parent, &prefix)) {
-		error = pr_err("ROA is not allowed to advertise %s/%u.",
+		error = pr_val_err("ROA is not allowed to advertise %s/%u.",
 		    v4addr2str(&prefix.addr), prefix.len);
 		goto end_error;
 	}
 
-	pr_debug("}");
+	pr_val_debug("}");
 	return vhandler_handle_roa_v4(asn, &prefix, max_length);
 end_error:
-	pr_debug("}");
+	pr_val_debug("}");
 	return error;
 }
 
@@ -90,27 +90,27 @@ ____handle_roa_v6(struct resources *parent, unsigned long asn,
 	if (error)
 		return error;
 
-	pr_debug("ROAIPAddress {");
-	pr_debug("address: %s/%u", v6addr2str(&prefix.addr), prefix.len);
+	pr_val_debug("ROAIPAddress {");
+	pr_val_debug("address: %s/%u", v6addr2str(&prefix.addr), prefix.len);
 
 	if (roa_addr->maxLength != NULL) {
 		error = asn_INTEGER2ulong(roa_addr->maxLength, &max_length);
 		if (error) {
 			if (errno)
-				pr_errno(errno, "Error casting ROA's IPv6 maxLength");
-			error = pr_err("The ROA's IPv6 maxLength isn't a valid unsigned long");
+				pr_val_errno(errno, "Error casting ROA's IPv6 maxLength");
+			error = pr_val_err("The ROA's IPv6 maxLength isn't a valid unsigned long");
 			goto end_error;
 		}
-		pr_debug("maxLength: %lu", max_length);
+		pr_val_debug("maxLength: %lu", max_length);
 
 		if (max_length > 128) {
-			error = pr_err("maxLength (%lu) is out of bounds (0-128).",
+			error = pr_val_err("maxLength (%lu) is out of bounds (0-128).",
 			    max_length);
 			goto end_error;
 		}
 
 		if (prefix.len > max_length) {
-			error = pr_err("Prefix length (%u) > maxLength (%lu)",
+			error = pr_val_err("Prefix length (%u) > maxLength (%lu)",
 			    prefix.len, max_length);
 			goto end_error;
 		}
@@ -120,15 +120,15 @@ ____handle_roa_v6(struct resources *parent, unsigned long asn,
 	}
 
 	if (!resources_contains_ipv6(parent, &prefix)) {
-		error = pr_err("ROA is not allowed to advertise %s/%u.",
+		error = pr_val_err("ROA is not allowed to advertise %s/%u.",
 		    v6addr2str(&prefix.addr), prefix.len);
 		goto end_error;
 	}
 
-	pr_debug("}");
+	pr_val_debug("}");
 	return vhandler_handle_roa_v6(asn, &prefix, max_length);
 end_error:
-	pr_debug("}");
+	pr_val_debug("}");
 	return error;
 }
 
@@ -143,7 +143,7 @@ ____handle_roa(struct resources *parent, unsigned long asn, uint8_t family,
 		return ____handle_roa_v6(parent, asn, roa_addr);
 	}
 
-	return pr_err("Unknown family value: %u", family);
+	return pr_val_err("Unknown family value: %u", family);
 }
 
 static int
@@ -156,18 +156,18 @@ __handle_roa(struct RouteOriginAttestation *roa, struct resources *parent)
 	int a;
 	int error;
 
-	pr_debug("eContent {");
+	pr_val_debug("eContent {");
 	if (roa->version != NULL) {
 		error = asn_INTEGER2ulong(roa->version, &version);
 		if (error) {
 			if (errno)
-				pr_errno(errno, "Error casting ROA's version");
-			error = pr_err("The ROA's version isn't a valid long");
+				pr_val_errno(errno, "Error casting ROA's version");
+			error = pr_val_err("The ROA's version isn't a valid long");
 			goto end_error;
 		}
 		/* rfc6482#section-3.1 */
 		if (version != 0) {
-			error = pr_err("ROA's version (%lu) is nonzero.",
+			error = pr_val_err("ROA's version (%lu) is nonzero.",
 			    version);
 			goto end_error;
 		}
@@ -176,29 +176,29 @@ __handle_roa(struct RouteOriginAttestation *roa, struct resources *parent)
 	/* rfc6482#section-3.2 */
 	if (asn_INTEGER2ulong(&roa->asID, &asn) != 0) {
 		if (errno)
-			pr_errno(errno, "Error casting ROA's AS ID value");
-		error = pr_err("ROA's AS ID couldn't be parsed as unsigned long");
+			pr_val_errno(errno, "Error casting ROA's AS ID value");
+		error = pr_val_err("ROA's AS ID couldn't be parsed as unsigned long");
 		goto end_error;
 	}
 
 	if (asn > UINT32_MAX) {
-		error = pr_err("AS value (%lu) is out of range.", asn);
+		error = pr_val_err("AS value (%lu) is out of range.", asn);
 		goto end_error;
 	}
-	pr_debug("asID: %lu", asn);
+	pr_val_debug("asID: %lu", asn);
 
 	/* rfc6482#section-3.3 */
 
 	if (roa->ipAddrBlocks.list.array == NULL) {
-		error = pr_err("ipAddrBlocks array is NULL.");
+		error = pr_val_err("ipAddrBlocks array is NULL.");
 		goto end_error;
 	}
 
-	pr_debug("ipAddrBlocks {");
+	pr_val_debug("ipAddrBlocks {");
 	for (b = 0; b < roa->ipAddrBlocks.list.count; b++) {
 		block = roa->ipAddrBlocks.list.array[b];
 		if (block == NULL) {
-			error = pr_err("Address block array element is NULL.");
+			error = pr_val_err("Address block array element is NULL.");
 			goto ip_error;
 		}
 
@@ -209,12 +209,12 @@ __handle_roa(struct RouteOriginAttestation *roa, struct resources *parent)
 		if (block->addressFamily.buf[1] != 1
 		    && block->addressFamily.buf[1] != 2)
 			goto family_error;
-		pr_debug("%s {",
+		pr_val_debug("%s {",
 		    block->addressFamily.buf[1] == 1 ? "v4" : "v6");
 
 		if (block->addresses.list.array == NULL) {
-			error = pr_err("ROA's address list array is NULL.");
-			pr_debug("}");
+			error = pr_val_err("ROA's address list array is NULL.");
+			pr_val_debug("}");
 			goto ip_error;
 		}
 
@@ -223,11 +223,11 @@ __handle_roa(struct RouteOriginAttestation *roa, struct resources *parent)
 			    block->addressFamily.buf[1],
 			    block->addresses.list.array[a]);
 			if (error) {
-				pr_debug("}");
+				pr_val_debug("}");
 				goto ip_error;
 			}
 		}
-		pr_debug("}");
+		pr_val_debug("}");
 	}
 
 	/* Error 0 it's ok */
@@ -235,11 +235,11 @@ __handle_roa(struct RouteOriginAttestation *roa, struct resources *parent)
 	goto ip_error;
 
 family_error:
-	error = pr_err("ROA's IP family is not v4 or v6.");
+	error = pr_val_err("ROA's IP family is not v4 or v6.");
 ip_error:
-	pr_debug("}");
+	pr_val_debug("}");
 end_error:
-	pr_debug("}");
+	pr_val_debug("}");
 	return error;
 }
 
@@ -255,7 +255,7 @@ roa_traverse(struct rpki_uri *uri, struct rpp *pp)
 	int error;
 
 	/* Prepare */
-	pr_debug("ROA '%s' {", uri_get_printable(uri));
+	pr_val_debug("ROA '%s' {", uri_val_get_printable(uri));
 	fnstack_push_uri(uri);
 
 	/* Decode */
@@ -291,6 +291,6 @@ revert_sobj:
 	signed_object_cleanup(&sobj);
 revert_log:
 	fnstack_pop();
-	pr_debug("}");
+	pr_val_debug("}");
 	return error;
 }
