@@ -491,13 +491,6 @@ tal_get_spki(struct tal *tal, unsigned char const **buffer, size_t *len)
 	*len = tal->spki_len;
 }
 
-static int
-handle_https_uri(struct rpki_uri *uri)
-{
-	return http_download_file(uri,
-	    reqs_errors_log_uri(uri_get_global(uri)));
-}
-
 /**
  * Performs the whole validation walkthrough on uri @uri, which is assumed to
  * have been extracted from a TAL.
@@ -535,38 +528,37 @@ handle_tal_uri(struct tal *tal, struct rpki_uri *uri, void *arg)
 	if (error)
 		return ENSURE_NEGATIVE(error);
 
-	do {
-		if (!thread_arg->sync_files) {
-			/* Look for local files */
-			if (!valid_file_or_dir(uri_get_local(uri), true, false,
-			    pr_val_errno)) {
-				validation_destroy(state);
-				return 0; /* Error already logged */
-			}
-			break;
-		}
-		/* Trying to sync, considering that the sync can be disabled */
+	if (thread_arg->sync_files) {
 		if (uri_is_rsync(uri)) {
 			if (!config_get_rsync_enabled()) {
 				validation_destroy(state);
-				return 0; /* Soft error */
+				return 0; /* Try some other TAL URI */
 			}
-			error = download_files(uri, true, false);
-			break;
+			error = rsync_download_files(uri, true, false);
+		} else /* HTTPS */ {
+			if (!config_get_http_enabled()) {
+				validation_destroy(state);
+				return 0; /* Try some other TAL URI */
+			}
+			error = http_download_file(uri,
+			    reqs_errors_log_uri(uri_get_global(uri)));
 		}
-		if (!config_get_http_enabled()) {
-			validation_destroy(state);
-			return 0; /* Soft error */
-		}
-		error = handle_https_uri(uri);
-	} while (0);
 
-	/* Friendly reminder: there's a positive error - EREQFAILED */
-	if (error) {
-		working_repo_push(uri_get_global(uri));
-		validation_destroy(state);
-		return pr_val_warn("TAL URI '%s' could not be downloaded.",
-		    uri_val_get_printable(uri));
+		/* Reminder: there's a positive error: EREQFAILED */
+		if (error) {
+			working_repo_push(uri_get_global(uri));
+			validation_destroy(state);
+			return pr_val_warn(
+			    "TAL URI '%s' could not be downloaded.",
+			    uri_val_get_printable(uri));
+		}
+	} else {
+		/* Look for local files */
+		if (!valid_file_or_dir(uri_get_local(uri), true, false,
+		    __pr_val_err)) {
+			validation_destroy(state);
+			return 0; /* Error already logged */
+		}
 	}
 
 	/* At least one URI was sync'd */
@@ -662,7 +654,7 @@ __handle_tal_uri_local(struct tal *tal, struct rpki_uri *uri, void *arg)
 	return handle_tal_uri(tal, uri, arg);
 }
 
-static void *
+static void
 do_file_validation(void *thread_arg)
 {
 	struct validation_thread *thread = thread_arg;
@@ -686,8 +678,9 @@ do_file_validation(void *thread_arg)
 	if (error > 0) {
 		error = 0;
 		goto destroy_tal;
-	} else if (error < 0)
+	} else if (error < 0) {
 		goto destroy_tal;
+	}
 
 	if (!thread->retry_local) {
 		error = pr_op_err("None of the URIs of the TAL '%s' yielded a successful traversal.",
@@ -711,7 +704,6 @@ end:
 	working_repo_cleanup();
 	fnstack_cleanup();
 	thread->exit_status = error;
-	return NULL;
 }
 
 static void
@@ -749,7 +741,8 @@ __do_file_validation(char const *tal_file, void *arg)
 	thread->retry_local = true;
 	thread->sync_files = true;
 
-	error = thread_pool_push(t_param->pool, do_file_validation, thread);
+	error = thread_pool_push(t_param->pool, thread->tal_file,
+	    do_file_validation, thread);
 	if (error) {
 		pr_op_err("Couldn't push a thread to do files validation");
 		goto free_tal_file;
