@@ -36,18 +36,6 @@
 #define RRDP_ATTR_URI		"uri"
 #define RRDP_ATTR_HASH		"hash"
 
-/* Array list to get deltas from notification file */
-DEFINE_ARRAY_LIST_STRUCT(deltas_parsed, struct delta_head *);
-DEFINE_ARRAY_LIST_FUNCTIONS(deltas_parsed, struct delta_head *, static)
-
-/* Context while reading an update notification */
-struct rdr_notification_ctx {
-	/* Data being parsed */
-	struct update_notification *notification;
-	/* Unordered list of deltas */
-	struct deltas_parsed deltas;
-};
-
 /* Context while reading a snapshot */
 struct rdr_snapshot_ctx {
 	/* Data being parsed */
@@ -162,10 +150,9 @@ base64_sanitize(char *content, char **out)
 		return error;
 
 	if (original_size <= BUF_SIZE) {
-		result = malloc(original_size + 1);
+		result = strdup(content);
 		if (result == NULL)
 			return pr_enomem();
-		result[original_size] = '\0';
 		*out = result;
 		return 0;
 	}
@@ -258,15 +245,17 @@ parse_string(xmlTextReaderPtr reader, char const *attr, char **result)
 	xmlChar *xml_value;
 	char *tmp;
 
-	if (attr == NULL)
+	if (attr == NULL) {
 		xml_value = xmlTextReaderValue(reader);
-	else
+		if (xml_value == NULL)
+			return pr_val_err("RRDP file: Couldn't find string content from '%s'",
+			    xmlTextReaderConstLocalName(reader));
+	} else {
 		xml_value = xmlTextReaderGetAttribute(reader, BAD_CAST attr);
-
-	if (xml_value == NULL)
-		return pr_val_err("RRDP file: Couldn't find %s from '%s'",
-		    (attr == NULL ? "string content" : "xml attribute"),
-		    xmlTextReaderConstLocalName(reader));
+		if (xml_value == NULL)
+			return pr_val_err("RRDP file: Couldn't find xml attribute '%s' from tag '%s'",
+			    attr, xmlTextReaderConstLocalName(reader));
+	}
 
 	tmp = malloc(xmlStrlen(xml_value) + 1);
 	if (tmp == NULL) {
@@ -575,7 +564,6 @@ write_from_uri(char const *location, unsigned char *content, size_t content_len,
     struct visited_uris *visited_uris)
 {
 	struct rpki_uri *uri;
-	struct stat stat;
 	FILE *out;
 	size_t written;
 	int error;
@@ -591,7 +579,7 @@ write_from_uri(char const *location, unsigned char *content, size_t content_len,
 		return error;
 	}
 
-	error = file_write(uri_get_local(uri), &out, &stat);
+	error = file_write(uri_get_local(uri), &out);
 	if (error) {
 		uri_refput(uri);
 		return error;
@@ -698,147 +686,54 @@ parse_withdraw_elem(xmlTextReaderPtr reader, struct visited_uris *visited_uris)
 	return 0;
 }
 
-static int
-rdr_notification_ctx_init(struct rdr_notification_ctx *ctx)
-{
-	deltas_parsed_init(&ctx->deltas);
-	return 0;
-}
-
-static void
-__delta_head_destroy(struct delta_head **delta_head)
-{
-	delta_head_destroy(*delta_head);
-}
-
-static void
-rdr_notification_ctx_cleanup(struct rdr_notification_ctx *ctx)
-{
-	if (ctx->deltas.array != NULL)
-		deltas_parsed_cleanup(&ctx->deltas, __delta_head_destroy);
-}
-
 static int
 parse_notification_delta(xmlTextReaderPtr reader,
-    struct rdr_notification_ctx *ctx)
+    struct update_notification *update)
 {
-	struct delta_head *tmp;
-	unsigned long serial;
+	struct delta_head delta;
 	int error;
 
-	error = delta_head_create(&tmp);
+	error = parse_long(reader, RRDP_ATTR_SERIAL, &delta.serial);
+	if (error)
+		return error;
+	error = parse_doc_data(reader, true, true, &delta.doc_data);
 	if (error)
 		return error;
 
-	error = parse_long(reader, RRDP_ATTR_SERIAL, &serial);
+	error = deltas_head_add(&update->deltas_list, &delta);
 	if (error)
-		goto delta_destroy;
-	tmp->serial = serial;
+		doc_data_cleanup(&delta.doc_data);
 
-	error = parse_doc_data(reader, true, true, &tmp->doc_data);
-	if (error)
-		goto delta_destroy;
-
-	error = deltas_parsed_add(&ctx->deltas, &tmp);
-	if (error)
-		goto delta_destroy;
-
-	return 0;
-delta_destroy:
-	delta_head_destroy(tmp);
 	return error;
 }
 
-static int
-order_notification_deltas(struct rdr_notification_ctx *ctx)
-{
-	struct delta_head **ptr;
-	array_index i;
-	int error;
-
-	error = deltas_head_set_size(ctx->notification->deltas_list,
-	    ctx->deltas.len);
-	if (error)
-		return error;
-
-	ARRAYLIST_FOREACH(&ctx->deltas, ptr, i) {
-		error = deltas_head_add(ctx->notification->deltas_list,
-		    ctx->notification->global_data.serial,
-		    (*ptr)->serial,
-		    (*ptr)->doc_data.uri,
-		    (*ptr)->doc_data.hash,
-		    (*ptr)->doc_data.hash_len);
-
-		if (!error)
-			continue;
-
-		if (error == -EINVAL)
-			return pr_val_err("Serial '%lu' at delta elements isn't part of a contiguous list of serials.",
-			    (*ptr)->serial);
-
-		if (error == -EEXIST)
-			return pr_val_err("Duplicated serial '%lu' at delta elements.",
-			    (*ptr)->serial);
-
-		return error;
-	}
-
-	/*
-	 * "If delta elements are included, they MUST form a contiguous
-	 * sequence of serial numbers starting at a revision determined by
-	 * the Repository Server, up to the serial number mentioned in the
-	 * notification element."
-	 *
-	 * If all expected elements are set, everything is ok.
-	 */
-	if (!deltas_head_values_set(ctx->notification->deltas_list))
-		return pr_val_err("Deltas listed don't have a contiguous sequence of serial numbers");
-
-	return 0;
-}
-
 static int
 xml_read_notification(xmlTextReaderPtr reader, void *arg)
 {
-	struct rdr_notification_ctx *ctx = arg;
-	xmlReaderTypes type;
+	struct update_notification *update = arg;
 	xmlChar const *name;
-	int error;
 
-	error = 0;
 	name = xmlTextReaderConstLocalName(reader);
-	type = xmlTextReaderNodeType(reader);
-	switch (type) {
+	switch (xmlTextReaderNodeType(reader)) {
 	case XML_READER_TYPE_ELEMENT:
 		if (xmlStrEqual(name, BAD_CAST RRDP_ELEM_DELTA)) {
-			error = parse_notification_delta(reader, ctx);
+			return parse_notification_delta(reader, update);
 		} else if (xmlStrEqual(name, BAD_CAST RRDP_ELEM_SNAPSHOT)) {
-			error = parse_doc_data(reader, true, true,
-			    &ctx->notification->snapshot);
+			return parse_doc_data(reader, true, true,
+			    &update->snapshot);
 		} else if (xmlStrEqual(name, BAD_CAST RRDP_ELEM_NOTIFICATION)) {
 			/* No need to validate session ID and serial */
-			error = parse_global_data(reader,
-			    &ctx->notification->global_data, NULL, 0);
-			/* Init context for deltas and snapshot */
-			rdr_notification_ctx_init(ctx);
-		} else {
-			return pr_val_err("Unexpected '%s' element", name);
+			return parse_global_data(reader,
+			    &update->global_data, NULL, 0);
 		}
-		break;
-	case XML_READER_TYPE_END_ELEMENT:
-		if (xmlStrEqual(name, BAD_CAST RRDP_ELEM_NOTIFICATION)) {
-			error = order_notification_deltas(ctx);
-			rdr_notification_ctx_cleanup(ctx);
-			return error; /* Error 0 is ok */
-		}
-		break;
-	default:
-		return 0;
-	}
 
-	if (error) {
-		rdr_notification_ctx_cleanup(ctx);
-		return error;
+		return pr_val_err("Unexpected '%s' element", name);
+
+	case XML_READER_TYPE_END_ELEMENT:
+		if (xmlStrEqual(name, BAD_CAST RRDP_ELEM_NOTIFICATION))
+			return deltas_head_sort(&update->deltas_list,
+			    update->global_data.serial);
+		break;
 	}
 
 	return 0;
@@ -847,30 +742,21 @@ xml_read_notification(xmlTextReaderPtr reader, void *arg)
 static int
 parse_notification(struct rpki_uri *uri, struct update_notification **file)
 {
-	struct rdr_notification_ctx ctx;
-	struct update_notification *tmp;
-	char *dup;
+	struct update_notification *result;
 	int error;
 
-	dup = strdup(uri_get_global(uri));
-	if (dup == NULL)
+	result = update_notification_create(uri_get_global(uri));
+	if (result == NULL)
 		return pr_enomem();
 
-	error = update_notification_create(&tmp);
-	if (error)
-		return error;
-
-	tmp->uri = dup;
-
-	ctx.notification = tmp;
 	error = relax_ng_parse(uri_get_local(uri), xml_read_notification,
-	    &ctx);
+	    result);
 	if (error) {
-		update_notification_destroy(tmp);
+		update_notification_destroy(result);
 		return error;
 	}
 
-	*file = tmp;
+	*file = result;
 	return 0;
 }
 
@@ -999,8 +885,9 @@ parse_delta(struct rpki_uri *uri, struct delta_head *parents_data,
 	ctx.expected_serial = parents_data->serial;
 	error = relax_ng_parse(uri_get_local(uri), xml_read_delta, &ctx);
 
-	/* Error 0 is ok */
 	delta_destroy(delta);
+	/* Error 0 is ok */
+
 pop_fnstack:
 	fnstack_pop();
 	return error;
@@ -1016,12 +903,14 @@ process_delta(struct delta_head *delta_head, void *arg)
 
 	head_data = &delta_head->doc_data;
 
-	pr_val_debug("Processing delta '%s'.", delta_head->doc_data.uri);
+	pr_val_debug("Processing delta '%s'.", head_data->uri);
 	error = uri_create_https_str_rrdp(&uri, head_data->uri,
 	    strlen(head_data->uri));
 	if (error)
 		return error;
 
+	fnstack_push_uri(uri);
+
 	error = download_file(uri, 0, args->log_operation);
 	if (error)
 		goto release_uri;
@@ -1031,6 +920,7 @@ process_delta(struct delta_head *delta_head, void *arg)
 	delete_from_uri(uri, NULL);
 	/* Error 0 its ok */
 release_uri:
+	fnstack_pop();
 	uri_refput(uri);
 	return error;
 }
@@ -1055,21 +945,23 @@ rrdp_parse_notification(struct rpki_uri *uri, bool log_operation, bool force,
 	if (uri == NULL || uri_is_rsync(uri))
 		pr_crit("Wrong call, trying to parse a non HTTPS URI");
 
-	pr_val_debug("Processing notification '%s'.", uri_get_global(uri));
+	fnstack_push_uri(uri);
+	pr_val_debug("Processing notification.");
+
 	last_update = 0;
 	if (!force) {
 		error = db_rrdp_uris_get_last_update(uri_get_global(uri), &last_update);
 		if (error && error != -ENOENT)
-			return error;
+			goto end;
 	}
 
 	error = download_file(uri, last_update, log_operation);
 	if (error < 0)
-		return error;
+		goto end;
 
 	/* Request error, stop processing to handle as such */
 	if (error == EREQFAILED)
-		return error;
+		goto end;
 
 	/*
 	 * Mark as visited, if it doesn't exists yet, there's no problem since
@@ -1078,26 +970,24 @@ rrdp_parse_notification(struct rpki_uri *uri, bool log_operation, bool force,
 	 */
 	vis_err = db_rrdp_uris_set_request_status(uri_get_global(uri),
 	    RRDP_URI_REQ_VISITED);
-	if (vis_err && vis_err != -ENOENT)
-		return pr_val_err("Couldn't mark '%s' as visited",
-		    uri_get_global(uri));
+	if (vis_err && vis_err != -ENOENT) {
+		error = pr_val_err("Couldn't mark file as visited.");
+		goto end;
+	}
 
 	/* No updates yet */
 	if (error > 0) {
 		delete_from_uri(uri, NULL);
 		*result = NULL;
-		return 0;
+		error = 0;
+		goto end;
 	}
 
-	fnstack_push_uri(uri);
 	error = parse_notification(uri, result);
-	delete_from_uri(uri, NULL);
-	if (error) {
-		fnstack_pop();
-		return error;
-	}
 
-	return 0;
+	delete_from_uri(uri, NULL);
+end:	fnstack_pop();
+	return error;
 }
 
 int
@@ -1117,6 +1007,8 @@ rrdp_parse_snapshot(struct update_notification *parent,
 	if (error)
 		return error;
 
+	fnstack_push_uri(uri);
+
 	error = download_file(uri, 0, log_operation);
 	if (error)
 		goto release_uri;
@@ -1126,6 +1018,7 @@ rrdp_parse_snapshot(struct update_notification *parent,
 	delete_from_uri(uri, NULL);
 	/* Error 0 is ok */
 release_uri:
+	fnstack_pop();
 	uri_refput(uri);
 	return error;
 }
@@ -1141,6 +1034,6 @@ rrdp_process_deltas(struct update_notification *parent,
 	args.visited_uris = visited_uris;
 	args.log_operation = log_operation;
 
-	return deltas_head_for_each(parent->deltas_list,
+	return deltas_head_for_each(&parent->deltas_list,
 	    parent->global_data.serial, cur_serial, process_delta, &args);
 }
