@@ -93,7 +93,7 @@ is_already_downloaded(struct rpki_uri *uri, struct uri_list *visited_uris)
 {
 	struct uri *cursor;
 
-	/* TODO (next iteration) this is begging for a radix trie. */
+	/* TODO (next iteration) this is begging for a hash set. */
 	SLIST_FOREACH(cursor, visited_uris, next)
 		if (is_descendant(cursor->uri, uri))
 			return true;
@@ -233,6 +233,7 @@ prepare_rsync(struct rpki_uri *uri, bool is_ta, char ***args, size_t *args_len)
 			copy_args[i + 1] = strdup(uri_get_local(uri));
 		else
 			copy_args[i + 1] = strdup(config_args->array[i]);
+
 		if (copy_args[i + 1] == NULL) {
 			release_args(copy_args, i);
 			return pr_enomem();
@@ -451,14 +452,15 @@ do_rsync(struct rpki_uri *uri, bool is_ta, bool log_operation)
 		if (WIFEXITED(child_status)) {
 			/* Happy path (but also sad path sometimes). */
 			error = WEXITSTATUS(child_status);
-			pr_val_debug("Child terminated with error code %d.",
+			pr_val_debug("The rsync sub-process terminated with error code %d.",
 			    error);
 			if (!error)
 				goto release_args;
 
 			if (retries == config_get_rsync_retry_count()) {
-				pr_val_warn("Max RSYNC retries (%u) reached on '%s', won't retry again.",
-				    retries, uri_get_global(uri));
+				if (retries > 0)
+					pr_val_warn("Max RSYNC retries (%u) reached on '%s', won't retry again.",
+					    retries, uri_get_global(uri));
 				error = EREQFAILED;
 				goto release_args;
 			}
