@@ -2,6 +2,8 @@
 
 #include <sys/types.h> /* AF_INET, AF_INET6 (needed in OpenBSD) */
 #include <sys/socket.h> /* AF_INET, AF_INET6 (needed in OpenBSD) */
+
+#include "log.h"
 #include "data_structure/uthash_nonfatal.h"
 
 struct hashable_roa {
@@ -132,81 +134,6 @@ add_router_key(struct db_table *table, struct hashable_key *new)
 	return 0;
 }
 
-static int
-duplicate_roa(struct db_table *dst, struct hashable_roa *new)
-{
-	struct vrp vrp;
-	struct ipv4_prefix prefix4;
-	struct ipv6_prefix prefix6;
-
-	vrp = new->data;
-	switch (vrp.addr_fam) {
-	case AF_INET:
-		prefix4.addr = vrp.prefix.v4;
-		prefix4.len = vrp.prefix_length;
-		return rtrhandler_handle_roa_v4(dst, vrp.asn, &prefix4,
-		    vrp.max_prefix_length);
-	case AF_INET6:
-		prefix6.addr = vrp.prefix.v6;
-		prefix6.len = vrp.prefix_length;
-		return rtrhandler_handle_roa_v6(dst, vrp.asn, &prefix6,
-		    vrp.max_prefix_length);
-	}
-
-	pr_crit("Unknown address family: %d", vrp.addr_fam);
-}
-
-static int
-duplicate_key(struct db_table *dst, struct hashable_key *new)
-{
-	return rtrhandler_handle_router_key(dst, new->data.ski, new->data.as,
-	    new->data.spk);
-}
-
-#define MERGE_ITER(table_prop, name, err_var)				\
-	struct hashable_##name *node_##name, *tmp_##name, *found_##name;\
-	HASH_ITER(hh, src->table_prop, node_##name, tmp_##name) {	\
-		HASH_FIND(hh, dst->table_prop, &node_##name->data,	\
-			sizeof(node_##name->data), found_##name);	\
-		if (found_##name != NULL)				\
-			continue;					\
-		err_var = duplicate_##name(dst, node_##name);		\
-		if (err_var)						\
-			return err_var;					\
-	}
-
-static int
-db_table_merge(struct db_table *dst, struct db_table *src)
-{
-	int error;
-
-	/** Must look for elements due to the new mem allocation */
-	MERGE_ITER(roas, roa, error)
-	MERGE_ITER(router_keys, key, error)
-
-	return 0;
-}
-
-int
-db_table_clone(struct db_table **dst, struct db_table *src)
-{
-	struct db_table *result;
-	int error;
-
-	result = db_table_create();
-	if (result == NULL)
-		return pr_enomem();
-
-	error = db_table_merge(result, src);
-	if (error) {
-		db_table_destroy(result);
-		return error;
-	}
-
-	*dst = result;
-	return 0;
-}
-
 unsigned int
 db_table_roa_count(struct db_table *table)
 {
@@ -306,30 +233,6 @@ rtrhandler_handle_router_key(struct db_table *table,
 	return error;
 }
 
-static int
-add_roa_delta(struct deltas *deltas, struct hashable_roa *roa, int op)
-{
-	union {
-		struct v4_address v4;
-		struct v6_address v6;
-	} addr;
-
-	switch (roa->data.addr_fam) {
-	case AF_INET:
-		addr.v4.prefix.addr = roa->data.prefix.v4;
-		addr.v4.prefix.len = roa->data.prefix_length;
-		addr.v4.max_length = roa->data.max_prefix_length;
-		return deltas_add_roa_v4(deltas, roa->data.asn, &addr.v4, op);
-	case AF_INET6:
-		addr.v6.prefix.addr = roa->data.prefix.v6;
-		addr.v6.prefix.len = roa->data.prefix_length;
-		addr.v6.max_length = roa->data.max_prefix_length;
-		return deltas_add_roa_v6(deltas, roa->data.asn, &addr.v6, op);
-	}
-
-	pr_crit("Unknown address family: %d", roa->data.addr_fam);
-}
-
 /*
  * Copies `@roas1 - roas2` into @deltas.
  *
@@ -346,7 +249,7 @@ add_roa_deltas(struct hashable_roa *roas1, struct hashable_roa *roas2,
 	for (n1 = roas1; n1 != NULL; n1 = n1->hh.next) {
 		HASH_FIND(hh, roas2, &n1->data, sizeof(n1->data), n2);
 		if (n2 == NULL) {
-			error = add_roa_delta(deltas, n1, op);
+			error = deltas_add_roa(deltas, &n1->data, op);
 			if (error)
 				return error;
 		}
