@@ -1,16 +1,15 @@
 #ifndef SRC_RTR_DB_DB_TABLE_H_
 #define SRC_RTR_DB_DB_TABLE_H_
 
+#include "types/address.h"
+#include "types/vrp.h"
 #include "rtr/db/delta.h"
-#include "rtr/db/vrp.h"
 
 struct db_table;
 
 struct db_table *db_table_create(void);
 void db_table_destroy(struct db_table *);
 
-int db_table_clone(struct db_table **, struct db_table *);
-
 unsigned int db_table_roa_count(struct db_table *);
 unsigned int db_table_router_key_count(struct db_table *);
 
