@@ -5,9 +5,9 @@
 #include <string.h>
 #include <syslog.h>
 
-#include "address.h"
 #include "common.h"
 #include "log.h"
+#include "types/address.h"
 #include "rtr/err_pdu.h"
 #include "rtr/pdu_handler.h"
 
