@@ -1,8 +1,6 @@
 #ifndef SRC_VISITED_URIS_H_
 #define SRC_VISITED_URIS_H_
 
-#include <stdbool.h>
-
 struct visited_uris;
 
 int visited_uris_create(struct visited_uris **);
@@ -11,6 +9,6 @@ void visited_uris_refget(struct visited_uris *);
 
 int visited_uris_add(struct visited_uris *, char const *);
 int visited_uris_remove(struct visited_uris *, char const *);
-int visited_uris_delete_local(struct visited_uris *);
+int visited_uris_delete_local(struct visited_uris *, char const *);
 
 #endif /* SRC_VISITED_URIS_H_ */
