@@ -6,7 +6,7 @@
 #include "log.c"
 #include "impersonator.c"
 #include "str_token.c"
-#include "uri.c"
+#include "types/uri.c"
 #include "rsync/rsync.c"
 
 
@@ -16,12 +16,6 @@ state_retrieve(void)
 	return NULL;
 }
 
-START_TEST(rsync_load_normal)
-{
-
-}
-END_TEST
-
 static void
 assert_descendant(bool expected, char *ancestor, char *descendant)
 {
@@ -141,10 +135,7 @@ END_TEST
 Suite *rsync_load_suite(void)
 {
 	Suite *suite;
-	TCase *core, *prefix_equals, *uri_list, *test_get_prefix;
-
-	core = tcase_create("Core");
-	tcase_add_test(core, rsync_load_normal);
+	TCase *prefix_equals, *uri_list, *test_get_prefix;
 
 	prefix_equals = tcase_create("PrefixEquals");
 	tcase_add_test(prefix_equals, rsync_test_prefix_equals);
@@ -156,7 +147,6 @@ Suite *rsync_load_suite(void)
 	tcase_add_test(test_get_prefix, rsync_test_get_prefix);
 
 	suite = suite_create("rsync_test()");
-	suite_add_tcase(suite, core);
 	suite_add_tcase(suite, prefix_equals);
 	suite_add_tcase(suite, uri_list);
 	suite_add_tcase(suite, test_get_prefix);
