@@ -11,8 +11,8 @@
 #include "log.c"
 #include "state.h"
 #include "str_token.c"
-#include "uri.c"
 #include "random.c"
+#include "types/uri.c"
 #include "crypto/base64.c"
 #include "rsync/rsync.c"
 #include "thread/thread_pool.c"
